@@ -1,10 +1,11 @@
+from . import tools
 from . import formula
 from . import linear
 from . import testing
 
 from .formula import (
     Factor, Term, Formula, Real, Categ, Demean, Binned, Custom,
-    I, R, C, D, B, robust_eval, factor, design_matrices
+    I, R, C, D, B, robust_eval, factor, design_matrix, design_matrices
 )
 from .linear import ols
 from .testing import dataset
